@@ -32,6 +32,7 @@ from zope.security.proxy import removeSecurityProxy
 from z3c.form.converter import BaseDataConverter
 from z3c.form.interfaces import IFieldWidget, IDataConverter
 from z3c.form.widget import Widget, FieldWidget
+from z3c.form.browser.widget import WidgetLayoutSupport
 
 from schooltool.contact.interfaces import IContactable, IContact, IUniqueFormKey
 from schooltool.contact.browser.relationship import get_relationship_title
@@ -237,7 +238,7 @@ class PersonListWidget(WidgetBase):
             return False
 
 
-class PersonListZ3CFormWidget(Widget, PersonListWidget):
+class PersonListZ3CFormWidget(Widget, WidgetLayoutSupport, PersonListWidget):
     """z3c form widget for PersonList field."""
 
     template = ViewPageTemplateFile('templates/f_person_list.pt')
